@@ -3,12 +3,16 @@ import logging
 import requests
 from FunctionalTests.FunctionalParam import FunctionalParam
 # from jsonpath_ng import jsonpath, parse
-from Config.Defaultheader import Defaultheader
+
 functionalParm = FunctionalParam()
 logger = logging.getLogger()
 logger.setLevel(logging.DEBUG)
-header = Defaultheader()
 
+try:
+	from Config.Defaultheader import Defaultheader
+	header = Defaultheader()
+except:
+	pass
 
 stagelink = "ifi/151613/"
 endpoint = "https://plutus.mum1-stage.zeta.in/plutus-onboarding/send/otp"
